<?php
/**
 * Plugin Name:          Products PDF Catalog
 * Plugin URI:           https://addify.store/product/woocommerce-store-catalog-pdf/
 * Description:          Enhance your store with Products PDF Catalog. Boost up the product display and downloads for a superior shopping experience.
 * Version:              1.1.0
 * Author:               Adiffy
 * Develop BY:           Addify
 * Author URI:           https://addify.store/
 * Support:              https://addify.store/
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:          products-pdf-catalog
 * WC required at least: 3.0.9
 * WC tested upto: 8.*.*
 */

if ( ! defined( 'ABSPATH' ) ) {
	die();
}
if ( ! class_exists( 'Products_Pdf_Catalog' ) ) {
	class Products_Pdf_Catalog {
		public function __construct() {
			$this->wc_sc_pdf_const_variables();
			add_action( 'init', array( $this, 'af_wcsc_pdf_woocommerce_check' ) );
			add_action( 'plugins_loaded', array( $this, 'af_wc_sc_pdf_woocommerce_check' ) );
			add_action( 'before_woocommerce_init', array( $this, 'af_wc_sc_pdf_hops_compatibility' ) );

			if ( file_exists( __DIR__ . '/vendor/autoload.php' ) ) {
				require_once __DIR__ . '/vendor/autoload.php';
			}
			register_activation_hook( __FILE__, array( $this, 'af_wc_sc_initial_settings' ) );
		}
		public function af_wc_sc_initial_settings(){

			$wc_sc_show_short_long_des = get_option( 'wc_sc_show_short_long_des' ) ? get_option( 'wc_sc_show_short_long_des' ) : 'long_description';
			update_option('wc_sc_show_short_long_des', $wc_sc_show_short_long_des);

			$wc_sc_show_btn_single_page = get_option( 'wc_sc_show_btn_single_page') ? get_option( 'wc_sc_show_btn_single_page') : 'woocommerce_before_single_product_summary';
			update_option('wc_sc_show_btn_single_page', $wc_sc_show_btn_single_page);

			$wc_sc_show_btn_cart_page = get_option( 'wc_sc_show_btn_cart_page') ? get_option( 'wc_sc_show_btn_cart_page') : 'woocommerce_before_cart';
			update_option('wc_sc_show_btn_cart_page', $wc_sc_show_btn_cart_page);

			$wc_sc_show_btn_shop_page = get_option( 'wc_sc_show_btn_shop_page') ? get_option( 'wc_sc_show_btn_shop_page') : 'woocommerce_archive_description';
			update_option('wc_sc_show_btn_shop_page', $wc_sc_show_btn_shop_page);

			$wc_sc_select_font = get_option( 'wc_sc_select_font') ? get_option( 'wc_sc_select_font') : 'Serif';
			update_option('wc_sc_select_font', $wc_sc_select_font);

			$wc_sc_download_btn_style = get_option( 'wc_sc_download_btn_style');
			$wc_sc_download_btn_default_value = array(
				'btn_text'=> 'Download PDF',
				'btn_clr' => 'blue',
				'text_clr'=> 'white'
			);
			if(!isset($wc_sc_download_btn_style) || empty($wc_sc_download_btn_style)){
				update_option('wc_sc_download_btn_style', $wc_sc_download_btn_default_value);
			}

			$wc_sc_send_email_btn_style = get_option( 'wc_sc_send_email_btn_style');
			$wc_sc_send_email_btn_style_default_value = array(
				'btn_text'=> 'Share PDF',
				'btn_clr' => 'blue',
				'text_clr'=> 'white'
			);
			if(!isset($wc_sc_send_email_btn_style) || empty($wc_sc_send_email_btn_style)){
				update_option('wc_sc_send_email_btn_style', $wc_sc_send_email_btn_style_default_value);
			}

			//----------------------------------- PDF settings----------------------------------------.
			$wc_sc_choose_template  = get_option( 'wc_sc_choose_template' ) ? get_option( 'wc_sc_choose_template' ) : 'wc_sc_temp3';
			update_option('wc_sc_choose_template', $wc_sc_choose_template);

			$wc_sc_temp1_template = get_option( 'wc_sc_temp1_template');

			$wc_sc_temp1_template_default_value = array(
				'top'=> 10,
				'right' => 0,
				'bottom'=> 10,
				'left'=> 0,
				'p1_color'=> '#f7d54d',
				'p1_text_color'=> 'black',
				'p2_color'=> '#fff1ad',
				'p2_text_color'=> 'black',
				'p3_color'=> 'black',
				'p3_text_color'=> 'white'
				
			);
			if(!isset($wc_sc_temp1_template) || empty($wc_sc_temp1_template)){
				update_option('wc_sc_temp1_template', $wc_sc_temp1_template_default_value);
			}

			$wc_sc_temp2_template = get_option( 'wc_sc_temp2_template');
			$wc_sc_temp2_template_default_value = array(
				'text_color'=> 'white',
				'bg_color' => 'black'

			);
			if(!isset($wc_sc_temp2_template) || empty($wc_sc_temp2_template)){
				update_option('wc_sc_temp2_template', $wc_sc_temp2_template_default_value);
			}

			$wc_sc_info_for_pdf = (array) get_option( 'wc_sc_info_for_pdf' );
			$wc_sc_info_for_pdf_default_value = array(
				'title'=> '1',
				'image' => '1',
				'Description' => '1',
				'price' => '1',
				'Categories' => '1',
				'skus' => '1',

			);
			if(!isset($wc_sc_info_for_pdf) || empty($wc_sc_info_for_pdf)){
				update_option('wc_sc_info_for_pdf', $wc_sc_info_for_pdf_default_value);
			}

			$wc_sc_header_logo_wh = (array) get_option( 'wc_sc_header_logo_wh' );
			$wc_sc_header_logo_wh_default_value = array(
				'width'=> 	'30',
				'height' => '30',

			);
			if(!isset($wc_sc_header_logo_wh)|| empty($wc_sc_header_logo_wh)){
				update_option('wc_sc_info_for_pdf', $wc_sc_header_logo_wh_default_value);
			}

			$wc_sc_header_logo_position = get_option( 'wc_sc_header_logo_position' ) ? get_option( 'wc_sc_header_logo_position' ) : 'left';
			update_option('wc_sc_header_logo_position', $wc_sc_header_logo_position);

			$wc_sc_header_padding = get_option( 'wc_sc_header_padding' );

			$wc_sc_header_padding_default_value = array(
				'top'=> '10',
				'right' => '10',
				'bottom' => '10',
				'left' => '10'

			);
			if(!isset($wc_sc_header_padding) || empty($wc_sc_header_padding)){
				update_option('wc_sc_header_padding', $wc_sc_header_padding_default_value);
			}

			$wc_sc_header_footer_text_color = get_option( 'wc_sc_header_footer_text_color' ) ? get_option( 'wc_sc_header_footer_text_color' ) : 'left';
			update_option('wc_sc_header_footer_text_color', $wc_sc_header_footer_text_color);

			$wc_sc_header_footer_bg_color = get_option( 'wc_sc_header_footer_bg_color' ) ? get_option( 'wc_sc_header_footer_bg_color' ) : 'left';
			update_option('wc_sc_header_footer_bg_color', $wc_sc_header_footer_bg_color);

		}
		public function af_wcsc_pdf_woocommerce_check() {
			if ( defined( 'WC_PLUGIN_FILE' ) ) {
				add_action( 'after_setup_theme', array( $this, 'af_wc_sc_pdf_load_text_domain' ) );
				require_once AF_WC_SC_PDF_PLUGIN_DIR . 'assets/ajax-controller/class-af-wc-ajax-controller.php';
				require_once AF_WC_SC_PDF_PLUGIN_DIR . 'includes/af-woocommerce-store-catalog-general-functions.php';

				if ( is_admin() ) {
					require_once AF_WC_SC_PDF_PLUGIN_DIR . 'includes/admin/class-af-woocomerce-store-catalog-pdf-admin.php';
				} else {
					require_once AF_WC_SC_PDF_PLUGIN_DIR . 'includes/front/class-af-woocommerce-store-catalog-pdf-front.php';
				}
			}
		}
		public function af_woocommerce_store_catalog_pdf_wc_active() {
			deactivate_plugins( __FILE__ );
			?>
			<div id="message" class="error">
				<p>
					<strong>
						<?php echo esc_html__( 'WooCommerce Store Catalog PDF plugin is inactive. WooCommerce plugin must be active in order to activate it.', 'products-pdf-catalog' ); ?>
					</strong>
				</p>
			</div>
			<?php
		}
		public function af_wc_sc_pdf_woocommerce_check() {
			if ( ! is_multisite() && ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) ) {
				add_action( 'admin_notices', array( $this, 'af_woocommerce_store_catalog_pdf_wc_active' ) );

			}
		}
		public function wc_sc_pdf_const_variables() {
			if ( ! defined( 'AF_WC_SC_PDF_PLUGIN_URL' ) ) {
				define( 'AF_WC_SC_PDF_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
			}
			if ( ! defined( 'AF_WC_SC_PDF_PLUGIN_DIR' ) ) {
				define( 'AF_WC_SC_PDF_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
			}
		}
		public function af_wc_sc_pdf_hops_compatibility() {
			if ( class_exists( \Automatic\WooCommerce\Utitlities\FeaturesUtil::class ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		}
		public function af_wc_sc_pdf_load_text_domain() {
			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'products-pdf-catalog', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			}
		}
	}
}
new Products_Pdf_Catalog();
?>
