<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
class Af_Woocommerce_Store_Catalog_Pdf_Front {
	public function __construct() {
		add_action( 'wp_enqueue_scripts', array( $this, 'sc_pdf_js_css_front_scripts' ) );

		$wc_sc_show_btn_single_page = get_option( 'wc_sc_show_btn_single_page' );
		$wc_sc_show_btn_cart_page   = get_option( 'wc_sc_show_btn_cart_page' );
		$wc_sc_show_btn_shop_page   = get_option( 'wc_sc_show_btn_shop_page' );

		add_action( $wc_sc_show_btn_single_page, array( $this, 'print_single_product_button_callback' ) );
		add_action( $wc_sc_show_btn_cart_page, array( $this, 'print_cart_products_button_callback' ) );
		add_action( $wc_sc_show_btn_shop_page, array( $this, 'print_shop_product_button_callback' ) );
		
		add_shortcode( 'download_custom_pdf', array( $this, 'wc_sc_ready_made_pdf_short_code_callback' ) );

		require_once AF_WC_SC_PDF_PLUGIN_DIR . 'includes/af-woocommerce-store-catalog-general-functions.php';
		require_once AF_WC_SC_PDF_PLUGIN_DIR . 'assets/ajax-controller/class-af-wc-ajax-controller.php';
	}
	public function checking_display_notification() {
		wc_add_notice('Email Sent Successfully!', 'success' );
	}
	public function wc_sc_ready_made_pdf_short_code_callback( $wc_sc_short_code_data ) {
		if ( ! function_exists( 'WP_Filesystem' ) ) {
			require_once ABSPATH . 'wp-admin/includes/file.php' ;
		}
		WP_Filesystem();
		global $wp_filesystem;
		$wc_sc_upload_folder = 'custom-pdfs';

		$wc_sc_image_path    = get_files_names_form_folder( $wc_sc_upload_folder );
		if ( isset( $_POST['wc_sc_ready_made_pdf_short_code'] ) ) {
			$nonce = isset( $_POST['af_wc_sc_shortcode_nonce_action'] ) ? sanitize_text_field( wp_unslash( $_POST['af_wc_sc_shortcode_nonce_action'] ) ) : 0;
			if ( ! wp_verify_nonce( $nonce, 'af_wc_sc_shortcode_nonce_name' ) ) {
				wp_die( esc_html__( 'Failed security check!', 'products-pdf-catalog' ) );
			}
			header( 'Content-Type: application/pdf' );
			header( 'Content-Transfer-Encoding: binary' );
			header( 'Content-Disposition: attachment; filename=custom_pdf.pdf' );
			header( 'Cache-Control: must-revalidate, post-check=0, pre-check=0' );
			header( 'Content-Length' . filesize( $wc_sc_image_path ) );
			ob_clean();
			flush();

			$file_content = $wp_filesystem->get_contents($wc_sc_image_path);
			if ( false !== $file_content) {
				ob_start();
				print $file_content;
				ob_end_flush();
			}
			exit();
		}
		if ( isset( $_POST['wc_sc_ready_made_pdf_short_code_view'] ) ) {
			$nonce = isset( $_POST['af_wc_sc_shortcode_nonce_action'] ) ? sanitize_text_field( wp_unslash( $_POST['af_wc_sc_shortcode_nonce_action'] ) ) : 0;
			if ( ! wp_verify_nonce( $nonce, 'af_wc_sc_shortcode_nonce_name' ) ) {
				wp_die( esc_html__( 'Failed security check!', 'products-pdf-catalog' ) );
			}
			wp_safe_redirect($wc_sc_image_path);
			exit();
		}
		ob_start();
		?>
		<form method="post">
			<?php wp_nonce_field( 'af_wc_sc_shortcode_nonce_name', 'af_wc_sc_shortcode_nonce_action' ); ?>
			<input type='submit' class='wc_sc_download_product' name='wc_sc_ready_made_pdf_short_code' value='Download PDF' />
			<input type='submit' class='wc_sc_download_product' name='wc_sc_ready_made_pdf_short_code_view' value='Preview PDF' />
		</form>
		<?php
		$wc_sc_short_code_data = ob_get_clean();
		return $wc_sc_short_code_data;
	}
	public function print_single_product_button_callback() {

		$wc_sc_download_btn   = get_option('wc_sc_download_btn_style');
		$wc_sc_send_email_btn = get_option('wc_sc_send_email_btn_style');

		$wc_sc_btn_text     = isset($wc_sc_download_btn['btn_text']) ? $wc_sc_download_btn['btn_text'] : 'Download PDF';
		$wc_sc_btn_clr      = isset($wc_sc_download_btn['btn_clr']) ? $wc_sc_download_btn['btn_clr'] : 'blue';
		$wc_sc_text_clr     = isset($wc_sc_download_btn['text_clr']) ? $wc_sc_download_btn['text_clr'] : 'white';

		$wc_sc_btn_text_email     = isset($wc_sc_send_email_btn['btn_text']) ? $wc_sc_send_email_btn['btn_text'] : 'Download PDF';
		$wc_sc_btn_clr_email      = isset($wc_sc_send_email_btn['btn_clr']) ? $wc_sc_send_email_btn['btn_clr'] : 'blue';
		$wc_sc_text_clr_email     = isset($wc_sc_send_email_btn['text_clr']) ? $wc_sc_send_email_btn['text_clr'] : 'white';

		$wc_sc_page_type_for_pdf = 'single_product_page';
		$wc_sc_alowed            = $this->check_roles_country_en_dis( $wc_sc_page_type_for_pdf );

		if ( true == $wc_sc_alowed ) {
			return;
		}
		if ( is_product() ) {
			$wc_sc_product_ids   = array();
			$wc_sc_product_ids[] = get_the_ID();

			if ( isset( $_POST['wc_sc_download_single_product'] ) ) {

				$nonce = isset( $_POST['af_wc_sc_send_email_nonce_action'] ) ? sanitize_text_field( wp_unslash( $_POST['af_wc_sc_send_email_nonce_action'] ) ) : 0;
				if ( ! wp_verify_nonce( $nonce, 'af_wc_sc_send_email_nonce_name' ) ) {
					wp_die( esc_html__( 'Failed security check!', 'products-pdf-catalog' ) );
				}
				$func_type = 'view';
				create_template_for_pdf( $wc_sc_product_ids, $func_type, 'category' );
			}

			if (isset( $_POST['wc_sc_email_send'] ) ) {
				$this->checking_display_notification();
			}
			$form_image           = get_option('wc_sc_form_logo') ? get_option('wc_sc_form_logo'): AF_WC_SC_PDF_PLUGIN_URL . '/assets/images/wcsc_img_placeholder.png';
			?>
			
			<div class="form-popup" id="myForm" >	
				<form method="post" class="form-container af-wcsc-send-pdf-email">
					<?php wp_nonce_field( 'af_wc_sc_send_email_nonce_name', 'af_wc_sc_send_email_nonce_action' ); ?>
					<div class="img_div_email_logo">
			<div class="loader" style="display:none; position:fixed;"></div>
					<img id="email_logo_img" src="<?php echo esc_url( $form_image ); ?>" />
				</div>
				<div class="af-wssc-container">
					<label for="Send To"><?php esc_html_e( 'Send To', 'products-pdf-catalog' ); ?></label>
					<input style="width: 300px;height:50px;" type="email" placeholder="Enter Email" required name="email" class="wcsc_email">
					<label><?php esc_html_e( 'Message', 'products-pdf-catalog' ); ?></label>
					<textarea class="wcsc_textarea" rows="3" cols="30" placeholder="Message..." name="wc_sc_textarea" required></textarea>
					<div class="wcsc_send_cancel_btn">
					<input type="submit"  id="wc_sc_email_send" class="wc_sc_email_send" name="wc_sc_email_send" value="Send Email"/>
					<button type="button" class="wc_sc_email_send_cancel wc_sc_email_send"><?php esc_html_e( 'Close', 'products-pdf-catalog' ); ?></button>
					</div>

					<input type="hidden"   aria-autocomplete=""name="product_id" value="<?php echo esc_attr( implode( '__', (array) $wc_sc_product_ids ) ); ?>">

				</div>
			</form>
			</div>

			<form method="post" target="_blank">
				<?php wp_nonce_field( 'af_wc_sc_send_email_nonce_name', 'af_wc_sc_send_email_nonce_action' ); ?>
				<input style="background-color: <?php echo esc_attr($wc_sc_btn_clr); ?>;color: <?php echo esc_attr($wc_sc_text_clr); ?>" type="submit" id="wc_sc_download_single_product" class="wc_sc_download_product" name="wc_sc_download_single_product" value="<?php echo esc_attr($wc_sc_btn_text); ?>" />
				<input style="background-color: <?php echo esc_attr($wc_sc_btn_clr_email); ?>;color: <?php echo esc_attr($wc_sc_text_clr_email); ?>" type="button" id="send_pdf_email" class="wc_sc_download_product send_pdf_email" name="wc_sc_download_single_product_email" value="<?php echo esc_attr($wc_sc_btn_text_email); ?>" />
			</form>
			<?php
		}
	}
	public function print_cart_products_button_callback() {

		$wc_sc_download_btn   = get_option('wc_sc_download_btn_style');
		$wc_sc_send_email_btn = get_option('wc_sc_send_email_btn_style');

		$wc_sc_btn_text     = isset($wc_sc_download_btn['btn_text']) ? $wc_sc_download_btn['btn_text'] : 'Download PDF';
		$wc_sc_btn_clr      = isset($wc_sc_download_btn['btn_clr']) ? $wc_sc_download_btn['btn_clr'] : 'blue';
		$wc_sc_text_clr      = isset($wc_sc_download_btn['text_clr']) ? $wc_sc_download_btn['text_clr'] : 'white';

		$wc_sc_btn_text_email     = isset($wc_sc_send_email_btn['btn_text']) ? $wc_sc_send_email_btn['btn_text'] : 'Download PDF';
		$wc_sc_btn_clr_email      = isset($wc_sc_send_email_btn['btn_clr']) ? $wc_sc_send_email_btn['btn_clr'] : 'blue';
		$wc_sc_text_clr_email     = isset($wc_sc_send_email_btn['text_clr']) ? $wc_sc_send_email_btn['text_clr'] : 'white';
		if ( is_cart() ) {
			$wc_sc_page_type_for_pdf = 'cart_page';
		}
		$wc_sc_alowed = $this->check_roles_country_en_dis( $wc_sc_page_type_for_pdf );

		if ( true == $wc_sc_alowed ) {
			return;
		}

		$wc_sc_cart        = WC()->cart;
		$wc_sc_product_ids = array();

		if ( ! $wc_sc_cart->is_empty() ) {
			foreach ( $wc_sc_cart->get_cart() as $wc_sc_cart_item_key => $wc_sc_cart_item ) {
				$wc_sc_product_id    = $wc_sc_cart_item['product_id'];
				$wc_sc_product_ids[] = $wc_sc_product_id;
			}
		}
		if ( isset( $_POST['wc_sc_download_cart_products'] ) ) {
			$nonce = isset( $_POST['af_wc_sc_send_email_nonce_action'] ) ? sanitize_text_field( wp_unslash( $_POST['af_wc_sc_send_email_nonce_action'] ) ) : 0;
			if ( ! wp_verify_nonce( $nonce, 'af_wc_sc_send_email_nonce_name' ) ) {
				wp_die( esc_html__( 'Failed security check!', 'products-pdf-catalog' ) );
			}
			$func_type = 'view';
			create_template_for_pdf( $wc_sc_product_ids, $func_type );
		}
		$form_image           = get_option('wc_sc_form_logo') ? get_option('wc_sc_form_logo'): AF_WC_SC_PDF_PLUGIN_URL . '/assets/images/wcsc_img_placeholder.png';
		?>
			<div class="form-popup" id="myForm">
			<form method="post" class="form-container af-wcsc-send-pdf-email">
			<?php wp_nonce_field( 'af_wc_sc_send_email_nonce_name', 'af_wc_sc_send_email_nonce_action' ); ?>
			<div class="img_div_email_logo">
			<div class="loader" style="display:none; position:fixed;"></div>
					<img id="email_logo_img" src="<?php echo esc_attr($form_image); ?>" />
				</div>
				<div class="af-wssc-container">
					<label for="Send To"><?php esc_html_e( 'Send To', 'products-pdf-catalog' ); ?></label>
					<input style="width: 300px;height:50px;" type="email" placeholder="Enter Email" required name="email" class="wcsc_email" >
					<label><?php esc_html_e( 'Message', 'products-pdf-catalog' ); ?></label>
					<textarea class="wcsc_textarea" rows="3" cols="30" required placeholder="Message..." name="wc_sc_textarea"></textarea>
					<div class="wcsc_send_cancel_btn">
					<input type="submit" id="wc_sc_email_send" class="wc_sc_email_send" name="wc_sc_email_send" value="Send Email" />
					<button type="button" class="wc_sc_email_send_cancel wc_sc_email_send"><?php esc_html_e( 'Close', 'products-pdf-catalog' ); ?></button>
					</div>
					<input type="hidden"   aria-autocomplete=""name="product_id" value="<?php echo esc_attr( implode( '__', (array) $wc_sc_product_ids ) ); ?>">

				</div>
			</form>
			</div>
			<form method="post" target="_blank">
				<?php wp_nonce_field( 'af_wc_sc_send_email_nonce_name', 'af_wc_sc_send_email_nonce_action' ); ?>
				<input style="background-color: <?php echo esc_attr($wc_sc_btn_clr); ?>;color: <?php echo esc_attr($wc_sc_text_clr); ?>" type="submit" id="wc_sc_download_single_product" class="wc_sc_download_product" name="wc_sc_download_cart_products" value="<?php echo esc_attr($wc_sc_btn_text); ?>" />
				<input style="background-color: <?php echo esc_attr($wc_sc_btn_clr_email); ?>;color: <?php echo esc_attr($wc_sc_text_clr_email); ?>" type="button" id="send_pdf_email" class="wc_sc_download_product send_pdf_email" name="wc_sc_download_single_product_email" value="<?php echo esc_attr($wc_sc_btn_text_email); ?>" />
			</form>
		<?php
	}
	public function get_cart_block_data() {

		$wc_sc_download_btn   = get_option('wc_sc_download_btn_style');
		$wc_sc_send_email_btn = get_option('wc_sc_send_email_btn_style');

		$wc_sc_btn_text     = isset($wc_sc_download_btn['btn_text']) ? $wc_sc_download_btn['btn_text'] : 'Download PDF';
		$wc_sc_btn_clr      = isset($wc_sc_download_btn['btn_clr']) ? $wc_sc_download_btn['btn_clr'] : 'blue';
		$wc_sc_text_clr      = isset($wc_sc_download_btn['text_clr']) ? $wc_sc_download_btn['text_clr'] : 'white';

		$wc_sc_btn_text_email     = isset($wc_sc_send_email_btn['btn_text']) ? $wc_sc_send_email_btn['btn_text'] : 'Download PDF';
		$wc_sc_btn_clr_email      = isset($wc_sc_send_email_btn['btn_clr']) ? $wc_sc_send_email_btn['btn_clr'] : 'blue';
		$wc_sc_text_clr_email     = isset($wc_sc_send_email_btn['text_clr']) ? $wc_sc_send_email_btn['text_clr'] : 'white';
		$wc_sc_page_type_for_pdf = '';
		if ( is_cart() ) {
			$wc_sc_page_type_for_pdf = 'cart_page';
		}
		$wc_sc_alowed = $this->check_roles_country_en_dis( $wc_sc_page_type_for_pdf );

		if ( true == $wc_sc_alowed ) {
			return;
		}

		$wc_sc_cart        = WC()->cart;
		$wc_sc_product_ids = array();

		if ( ! $wc_sc_cart->is_empty() ) {
			foreach ( $wc_sc_cart->get_cart() as $wc_sc_cart_item_key => $wc_sc_cart_item ) {
				$wc_sc_product_id    = $wc_sc_cart_item['product_id'];
				$wc_sc_product_ids[] = $wc_sc_product_id;
			}
		}
		if ( isset( $_POST['wc_sc_download_cart_products'] ) ) {
			$nonce = isset( $_POST['af_wc_sc_send_email_nonce_action'] ) ? sanitize_text_field( wp_unslash( $_POST['af_wc_sc_send_email_nonce_action'] ) ) : 0;
			if ( ! wp_verify_nonce( $nonce, 'af_wc_sc_send_email_nonce_name' ) ) {
				wp_die( esc_html__( 'Failed security check!', 'products-pdf-catalog' ) );
			}
			$func_type = 'view';
			create_template_for_pdf( $wc_sc_product_ids, $func_type );
		}

		ob_start();
		$form_image           = get_option('wc_sc_form_logo') ? get_option('wc_sc_form_logo'): AF_WC_SC_PDF_PLUGIN_URL . '/assets/images/wcsc_img_placeholder.png';
		?>
			<div class="form-popup" id="myForm">
			<form method="post" class="form-container af-wcsc-send-pdf-email">
			<?php wp_nonce_field( 'af_wc_sc_send_email_nonce_name', 'af_wc_sc_send_email_nonce_action' ); ?>
			<div class="img_div_email_logo">
			<div class="loader" style="display:none; position:fixed;"></div>
					<img id="email_logo_img" src="<?php echo esc_attr($form_image); ?>" />
				</div>
				<div class="af-wssc-container">
					<label for="Send To"><?php esc_html_e( 'Send To', 'products-pdf-catalog' ); ?></label>
					<input style="width: 300px;height:50px;" type="email" placeholder="Enter Email" required name="email" class="wcsc_email" >
					<label><?php esc_html_e( 'Message', 'products-pdf-catalog' ); ?></label>
					<textarea class="wcsc_textarea" rows="3" cols="30" required placeholder="Message..." name="wc_sc_textarea"></textarea>
					<div class="wcsc_send_cancel_btn">
					<input type="submit" id="wc_sc_email_send" class="wc_sc_email_send" name="wc_sc_email_send" value="Send Email" />
					<button type="button" class="wc_sc_email_send_cancel wc_sc_email_send"><?php esc_html_e( 'Close', 'products-pdf-catalog' ); ?></button>
					</div>
					<input type="hidden"   aria-autocomplete=""name="product_id" value="<?php echo esc_attr( implode( '__', (array) $wc_sc_product_ids ) ); ?>">

				</div>
			</form>
			</div>
			<form method="post" target="_blank">
				<?php wp_nonce_field( 'af_wc_sc_send_email_nonce_name', 'af_wc_sc_send_email_nonce_action' ); ?>
				<input style="background-color: <?php echo esc_attr($wc_sc_btn_clr); ?>;color: <?php echo esc_attr($wc_sc_text_clr); ?>" type="submit" id="wc_sc_download_single_product" class="wc_sc_download_product" name="wc_sc_download_cart_products" value="<?php echo esc_attr($wc_sc_btn_text); ?>" />
				<input style="background-color: <?php echo esc_attr($wc_sc_btn_clr_email); ?>;color: <?php echo esc_attr($wc_sc_text_clr_email); ?>" type="button" id="send_pdf_email" class="wc_sc_download_product send_pdf_email" name="wc_sc_download_single_product_email" value="<?php echo esc_attr($wc_sc_btn_text_email); ?>" />
			</form>
		<?php
		return ob_get_clean();
	}
	public function print_shop_product_button_callback() {

		$wc_sc_download_btn   = get_option('wc_sc_download_btn_style');
		$wc_sc_send_email_btn = get_option('wc_sc_send_email_btn_style');

		$wc_sc_btn_text     = isset($wc_sc_download_btn['btn_text']) ? $wc_sc_download_btn['btn_text'] : 'Download PDF';
		$wc_sc_btn_clr      = isset($wc_sc_download_btn['btn_clr']) ? $wc_sc_download_btn['btn_clr'] : 'blue';

		$wc_sc_text_clr     = isset($wc_sc_download_btn['text_clr']) ? $wc_sc_download_btn['text_clr'] : 'white';
		

		$wc_sc_btn_text_email     = isset($wc_sc_send_email_btn['btn_text']) ? $wc_sc_send_email_btn['btn_text'] : 'Send PDF';
		$wc_sc_btn_clr_email      = isset($wc_sc_send_email_btn['btn_clr']) ? $wc_sc_send_email_btn['btn_clr'] : 'blue';


		$wc_sc_text_clr_email      = isset($wc_sc_send_email_btn['text_clr']) ? $wc_sc_send_email_btn['text_clr'] : 'white';
		$wc_sc_page_type_for_pdf  = 'shop_page';
		$wc_sc_alowed             = $this->check_roles_country_en_dis( $wc_sc_page_type_for_pdf );

		if ( true == $wc_sc_alowed ) {
			return;
		}


		$page_type = 'shop_page';
		if ( is_shop() ) {

			$wc_sc_product_ids = array();
			// Get the products in the main shop loop.
			while ( have_posts() ) {
				the_post();
				$wc_sc_product_ids[] = get_the_ID();
			}
		}

		if ( is_product_tag() ) {
			$page_type = 'tag_page';
			$wc_sc_product_ids = array();
			// Get the products in the main shop loop.
			while ( have_posts() ) {
				the_post();
				$wc_sc_product_ids[] = get_the_ID();
			}
		}
		if ( is_product_category() ) {
			$page_type = 'category_page';
			$wc_sc_product_ids = array();
			// Get the products in the main shop loop.
			while ( have_posts() ) {
				the_post();
				$wc_sc_product_ids[] = get_the_ID();
			}
		}

		if ( isset( $_POST['wc_sc_download_shop_products'] ) ) {
			$nonce = isset( $_POST['af_wc_sc_send_email_nonce_action'] ) ? sanitize_text_field( wp_unslash( $_POST['af_wc_sc_send_email_nonce_action'] ) ) : 0;
			if ( ! wp_verify_nonce( $nonce, 'af_wc_sc_send_email_nonce_name' ) ) {
				wp_die( esc_html__( 'Failed security check!', 'products-pdf-catalog' ) );
			}
			$func_type = 'view';    
			create_template_for_pdf( $wc_sc_product_ids, $func_type, $page_type );
		}

		$form_image           = get_option('wc_sc_form_logo') ? get_option('wc_sc_form_logo'): AF_WC_SC_PDF_PLUGIN_URL . '/assets/images/wcsc_img_placeholder.png';
		?>
			<div class="form-popup" id="myForm">
			<form method="post" class="form-container af-wcsc-send-pdf-email">
			<?php wp_nonce_field( 'af_wc_sc_send_email_nonce_name', 'af_wc_sc_send_email_nonce_action' ); ?>
			<div class="img_div_email_logo">
			<div class="loader" style="display:none; position:fixed;"></div>
					<img id="email_logo_img" src="<?php echo esc_attr($form_image); ?>" />
				</div>
				<div class="af-wssc-container">
					<label for="Send To"><?php esc_html_e( 'Send To', 'products-pdf-catalog' ); ?></label>
					<input style="width: 300px;height:50px;" type="email" placeholder="Enter Email" required name="email" class="wcsc_email" >

					<label><?php esc_html_e( 'Message', 'products-pdf-catalog' ); ?></label>
					<textarea class="wcsc_textarea" rows="3" cols="30" required placeholder="Message..."name="wc_sc_textarea"></textarea>
					<div class="wcsc_send_cancel_btn">
					<input type="submit" id="wc_sc_email_send" class="wc_sc_email_send" name="wc_sc_email_send" value="Send Email" />
					<button type="button" class="wc_sc_email_send_cancel wc_sc_email_send"><?php esc_html_e( 'Close', 'products-pdf-catalog' ); ?></button>
					</div>
					<input type="hidden"   aria-autocomplete="" name="product_id" value="<?php echo esc_attr( implode( '__', (array) $wc_sc_product_ids ) ); ?>">

				</div>
			</form>
			</div>
			<form method="post" target="_blank">
				<?php wp_nonce_field( 'af_wc_sc_send_email_nonce_name', 'af_wc_sc_send_email_nonce_action' ); ?>
				<input style="background-color: <?php echo esc_attr($wc_sc_btn_clr); ?>;color: <?php echo esc_attr($wc_sc_text_clr); ?>" type="submit" id="wc_sc_download_single_product" class="wc_sc_download_product" name="wc_sc_download_shop_products" value="<?php echo esc_attr($wc_sc_btn_text); ?>"/>
				<input style="background-color: <?php echo esc_attr($wc_sc_btn_clr_email); ?>;color: <?php echo esc_attr($wc_sc_text_clr_email); ?>" type="button" id="send_pdf_email" class="wc_sc_download_product send_pdf_email" name="wc_sc_download_single_product_email" value="<?php echo esc_attr($wc_sc_btn_text_email); ?>"/>
			</form>
		<?php
	}
	public function sc_pdf_js_css_front_scripts() {
		$af_sc_pdf_js_path_front  = AF_WC_SC_PDF_PLUGIN_URL . 'assets/js/af-woocommerce-store-catalog-pdf-front.js';
		$af_sc_pdf_css_path_front = AF_WC_SC_PDF_PLUGIN_URL . 'assets/css/af-woocommerce-store-catalog-pdf-front.css';
		wp_enqueue_script( 'af_wc_sc_pdf_js_script_front', $af_sc_pdf_js_path_front, array( 'jquery' ), '4.5.0', true );
		wp_enqueue_style( 'af_wc_sc_pdf_css_script_front', $af_sc_pdf_css_path_front, '', '1.0.0', '', true );

		$ajax_data = array(
			'ajax_url' => admin_url( 'admin-ajax.php' ),
			'nonce'=> wp_create_nonce('nonce_for_block_btn'),
			'get_cart_block_data'=>$this->get_cart_block_data(),
			'wc_sc_show_btn_cart_page' => get_option('wc_sc_show_btn_cart_page'),
		);
		wp_localize_script( 'af_wc_sc_pdf_js_script_front', 'af_wc_sc_pdf_ajax_data_front', $ajax_data);
	}
	public function check_roles_country_en_dis( $wc_sc_page_type_for_pdf ) {
		$af_min_max_location_obj = new WC_Geolocation();
		if ( isset( $_SERVER['REMOTE_ADDR'] ) ) {
			$af_wc_sc_current_ip = sanitize_text_field( wp_unslash( $_SERVER['REMOTE_ADDR'] ) );
		}
		$wc_sc_en_dis_single_product_pdf = get_option( 'wc_sc_en_dis_single_product_pdf' );
		$wc_sc_en_dis_shop_products      = get_option( 'wc_sc_en_dis_shop_products' );
		$wc_sc_en_dis_cart_products      = get_option( 'wc_sc_en_dis_cart_products' );

		$af_wc_sc_current_country   = $af_min_max_location_obj->geolocate_ip( $af_wc_sc_current_ip );
		$wc_sc_current_country_code = $af_wc_sc_current_country['country'];
		$wc_sc_user_role            = is_user_logged_in() ? current( wp_get_current_user()->roles ) : 'guest';
		$wc_sc_en_dis_roles_pdf     = (array) get_option( 'wc_sc_en_dis_roles_pdf' );
		$wc_sc_en_dis_countries_pdf = (array) get_option( 'wc_sc_en_dis_countries_pdf' );
		
		$af_wc_sc_role_country_value_flag = false;

		if ( in_array( $wc_sc_user_role, $wc_sc_en_dis_roles_pdf ) ) {
			$af_wc_sc_role_country_value_flag = true;
		}
		if ( ! empty( array_filter( $wc_sc_en_dis_countries_pdf, 'strlen' ) ) && in_array( $wc_sc_current_country_code, $wc_sc_en_dis_countries_pdf ) ) {
			$af_wc_sc_role_country_value_flag = true;
		}
		if ( empty( $wc_sc_en_dis_single_product_pdf ) && 'single_product_page' == $wc_sc_page_type_for_pdf ) {
			$af_wc_sc_role_country_value_flag = true;
		}
		if ( empty( $wc_sc_en_dis_cart_products ) && 'cart_page' == $wc_sc_page_type_for_pdf ) {
			$af_wc_sc_role_country_value_flag = true;
		}
		if ( empty( $wc_sc_en_dis_shop_products ) && 'shop_page' == $wc_sc_page_type_for_pdf ) {
			$af_wc_sc_role_country_value_flag = true;
		}
		return $af_wc_sc_role_country_value_flag;
	}
}
new Af_Woocommerce_Store_Catalog_Pdf_Front();

?>
